var group__speakerArrangements =
[
    [ "getChannelCount", "group__speakerArrangements.html#gaa8258a29fe4e3164d9239869c1afc1e0", null ],
    [ "getSpeakerIndex", "group__speakerArrangements.html#ga5e43f8bd9b65e001e85706fb6229e54d", null ],
    [ "getSpeaker", "group__speakerArrangements.html#ga365c311dce7ea3c41e6674d0c31893d9", null ],
    [ "isSubsetOf", "group__speakerArrangements.html#gaf586d67f2382fd76829515ec1a845f0d", null ],
    [ "isAuro", "group__speakerArrangements.html#gaa3a2c80faffa004172a77e983fd1d4ba", null ],
    [ "hasTopSpeakers", "group__speakerArrangements.html#ga2fd1d5b534428e6414e46829089313f9", null ],
    [ "hasBottomSpeakers", "group__speakerArrangements.html#ga20ceaf9e134bcb9d31d268f2bca6f990", null ],
    [ "hasMiddleSpeakers", "group__speakerArrangements.html#ga8560db7870831957b1862d500a9707b1", null ],
    [ "hasLfe", "group__speakerArrangements.html#gae80135ca5a48c012ae56eba60aed8ba7", null ],
    [ "is3D", "group__speakerArrangements.html#gae5b25533bf821c6470e9d5a8d37b2f08", null ],
    [ "isAmbisonics", "group__speakerArrangements.html#ga1eb079a06c32ed8dfe5640d1ea129beb", null ],
    [ "convertSpeaker_Ambi_1234Order_to_Ambi567Order", "group__speakerArrangements.html#ga3e1ccb637aac3918a31d5b061bcaabe4", null ],
    [ "convertSpeaker_Ambi_567Order_to_Ambi1234Order", "group__speakerArrangements.html#gae74e19a6a7653396d1c0e91ff85de6cb", null ],
    [ "getSpeakerArrangementFromString", "group__speakerArrangements.html#gae59865c6f6e439696b408a8e3a35fb67", null ],
    [ "getSpeakerArrangementString", "group__speakerArrangements.html#ga8f3040f601ddc82b7ff76bd0ac66b32b", null ],
    [ "getSpeakerShortName", "group__speakerArrangements.html#gaea8fb2e63d819b83b1811645b5f5c0a0", null ],
    [ "kSpeakerL", "group__speakerArrangements.html#ga851521dbd075cd021659099076c16157", null ],
    [ "kSpeakerR", "group__speakerArrangements.html#ga65243b42de36e6437862e02afb83ca72", null ],
    [ "kSpeakerC", "group__speakerArrangements.html#gabe9f3f14a428188b0fd0a229f15bf580", null ],
    [ "kSpeakerLfe", "group__speakerArrangements.html#gad73c9bd8399f3587e67bbaf199ae60a6", null ],
    [ "kSpeakerLs", "group__speakerArrangements.html#ga29b55e791de7fa8d4efdb6948d40db09", null ],
    [ "kSpeakerRs", "group__speakerArrangements.html#ga6509637bddb202148260ec274274c878", null ],
    [ "kSpeakerLc", "group__speakerArrangements.html#ga77b0a85020c9d06cd53d92a9f87fe6ad", null ],
    [ "kSpeakerRc", "group__speakerArrangements.html#gae771dcd8cf33e293b56b78ea7693544c", null ],
    [ "kSpeakerS", "group__speakerArrangements.html#ga6e55ae87f6e0a3e7cf8e66ad0e631774", null ],
    [ "kSpeakerCs", "group__speakerArrangements.html#ga5bc2d21ba0124c11a763e86ab63679ea", null ],
    [ "kSpeakerSl", "group__speakerArrangements.html#ga5380a69a0e649db11601a5841690ee2d", null ],
    [ "kSpeakerSr", "group__speakerArrangements.html#gae74ef8bbc9cc9012e28c09893fc80b6e", null ],
    [ "kSpeakerTc", "group__speakerArrangements.html#gac69d39d0c88807b942731d970506c02d", null ],
    [ "kSpeakerTfl", "group__speakerArrangements.html#ga51b0837ee59b85d8c61c7aaee975f55a", null ],
    [ "kSpeakerTfc", "group__speakerArrangements.html#ga6da088d7aa080b79f6dfa9a868bdb022", null ],
    [ "kSpeakerTfr", "group__speakerArrangements.html#ga7289205c458e1f2ec529f75ec40f68e1", null ],
    [ "kSpeakerTrl", "group__speakerArrangements.html#gaea0ef00845b9443a18b63572e3c6338a", null ],
    [ "kSpeakerTrc", "group__speakerArrangements.html#ga6aa3de86b02b284c84c12c3e3a772a7d", null ],
    [ "kSpeakerTrr", "group__speakerArrangements.html#ga97ce8834f00cbf7ffb2e4610f9aba296", null ],
    [ "kSpeakerLfe2", "group__speakerArrangements.html#gaac7d0cfc4cfa58abd88acd718b712f7b", null ],
    [ "kSpeakerM", "group__speakerArrangements.html#ga5756399f47d692e0e5e587bcc8a06a9d", null ],
    [ "kSpeakerACN0", "group__speakerArrangements.html#ga00ba599749f21d817eb4721f10d16ab7", null ],
    [ "kSpeakerACN1", "group__speakerArrangements.html#gad03f321035ce5552ec0a8145a147585b", null ],
    [ "kSpeakerACN2", "group__speakerArrangements.html#ga55be9946868c6ffe425dbdd9abc70843", null ],
    [ "kSpeakerACN3", "group__speakerArrangements.html#ga4b0a12de443ae669b9dce39400837571", null ],
    [ "kSpeakerACN4", "group__speakerArrangements.html#ga6f4ffe7c8d6138ddeb7c93dc971ffa1c", null ],
    [ "kSpeakerACN5", "group__speakerArrangements.html#ga6fad4bb1852d158b0aee5a5b324750de", null ],
    [ "kSpeakerACN6", "group__speakerArrangements.html#ga38bd79e07efa7b1b2825a614e25e597e", null ],
    [ "kSpeakerACN7", "group__speakerArrangements.html#ga7da30e8a25cd20fc4b44a292368092fc", null ],
    [ "kSpeakerACN8", "group__speakerArrangements.html#ga4d03f739a3250bd1cf51152ca75390ea", null ],
    [ "kSpeakerACN9", "group__speakerArrangements.html#ga6d70109a287e2108ea5e9e6e020185d0", null ],
    [ "kSpeakerACN10", "group__speakerArrangements.html#ga1a373406598a8f7208d98e94a039d377", null ],
    [ "kSpeakerACN11", "group__speakerArrangements.html#ga2a834a6c97df49e2fa45315ff7045533", null ],
    [ "kSpeakerACN12", "group__speakerArrangements.html#ga9cf6c4325c79c1b83ced8529fa7aa4cf", null ],
    [ "kSpeakerACN13", "group__speakerArrangements.html#ga1604729c414047881e20341108871354", null ],
    [ "kSpeakerACN14", "group__speakerArrangements.html#ga3633546c0ee46e3c70c52843faf722e6", null ],
    [ "kSpeakerACN15", "group__speakerArrangements.html#gae7a63dcd11e24560783142099359dca4", null ],
    [ "kSpeakerACN16", "group__speakerArrangements.html#gaf6a1083557b66bb33ab237b2894aa0fa", null ],
    [ "kSpeakerACN17", "group__speakerArrangements.html#gafd02153e1c7df908d78dba3344573ecb", null ],
    [ "kSpeakerACN18", "group__speakerArrangements.html#ga91318c6519398caaa67b5f1656167936", null ],
    [ "kSpeakerACN19", "group__speakerArrangements.html#ga3531cf9980f8fbeb289280f70cb82eb0", null ],
    [ "kSpeakerACN20", "group__speakerArrangements.html#ga34c39373e8684ea0bdd623206d23f92a", null ],
    [ "kSpeakerACN21", "group__speakerArrangements.html#ga59a627e4f770f658147db9ae99012a86", null ],
    [ "kSpeakerACN22", "group__speakerArrangements.html#ga1f29f3c176afccd1a3b9572cbc58ded3", null ],
    [ "kSpeakerACN23", "group__speakerArrangements.html#ga979239f98d73f46be915cf0d2600c8e6", null ],
    [ "kSpeakerACN24", "group__speakerArrangements.html#ga41826ce2877ff6e8fc93c8d4aa85647e", null ],
    [ "kSpeakerTsl", "group__speakerArrangements.html#gae27ef071e8ea85bdb2d5e35cb72c4313", null ],
    [ "kSpeakerTsr", "group__speakerArrangements.html#gac5f061a31de54df1c627e9ec947ac442", null ],
    [ "kSpeakerLcs", "group__speakerArrangements.html#gac91567b9c8119eb78d51f6cc398bd97f", null ],
    [ "kSpeakerRcs", "group__speakerArrangements.html#gaf9740e0213852cf05d6352dc4132b0df", null ],
    [ "kSpeakerBfl", "group__speakerArrangements.html#ga0874c430db7340ecf1c48962eaf436d0", null ],
    [ "kSpeakerBfc", "group__speakerArrangements.html#gac45ef96ed94ff6232edffe4924f63e39", null ],
    [ "kSpeakerBfr", "group__speakerArrangements.html#ga2d6583c536b80d854cbd733eea9877f9", null ],
    [ "kSpeakerPl", "group__speakerArrangements.html#gafc605342356ba44807fd1fa424a2bfe5", null ],
    [ "kSpeakerPr", "group__speakerArrangements.html#ga5fb93993f0b3c038be5073e228dbb2b7", null ],
    [ "kSpeakerBsl", "group__speakerArrangements.html#ga509a5cd9d9498ef62bdbce91425522f5", null ],
    [ "kSpeakerBsr", "group__speakerArrangements.html#ga541bc43dc24e1a4d36ef35220c5c8ac2", null ],
    [ "kSpeakerBrl", "group__speakerArrangements.html#ga7932bc1e145b3d3c9d2d8b771dfe7626", null ],
    [ "kSpeakerBrc", "group__speakerArrangements.html#gaa8f469e8c1955c1aea25d0e6ad85b18e", null ],
    [ "kSpeakerBrr", "group__speakerArrangements.html#ga3818a39d5d27234b78a6dfa41385c749", null ],
    [ "kEmpty", "group__speakerArrangements.html#ga85ed4946e3abe83c91baa3e14d6a5e54", null ],
    [ "kMono", "group__speakerArrangements.html#ga571ff835d603ec5e98e54f1e0feca20e", null ],
    [ "kStereo", "group__speakerArrangements.html#ga9b5733786c71156513982991fa5f3c11", null ],
    [ "kStereoSurround", "group__speakerArrangements.html#gaad38856abd90805d1e85fe737677bbe8", null ],
    [ "kStereoCenter", "group__speakerArrangements.html#ga44710b9a538279e604b98213e8acdbec", null ],
    [ "kStereoSide", "group__speakerArrangements.html#ga98918bef7ba906d9b970ba49fb02a742", null ],
    [ "kStereoCLfe", "group__speakerArrangements.html#gabec483e2214863d8fbfd2f68815647a8", null ],
    [ "kStereoTF", "group__speakerArrangements.html#ga350fe92a4a9f185ff5a7141e7cbada14", null ],
    [ "kStereoTS", "group__speakerArrangements.html#ga87a09b7b3ca62380f9203bcf6560a3a0", null ],
    [ "kStereoTR", "group__speakerArrangements.html#gab4b759bc9adbcb09a13453cab2916281", null ],
    [ "kStereoBF", "group__speakerArrangements.html#gadad8ca7e56a1171c6439875261ab1ce0", null ],
    [ "kCineFront", "group__speakerArrangements.html#gadfcb28a735791e8b21d3150fa254a4fe", null ],
    [ "k30Cine", "group__speakerArrangements.html#ga32b8626cc036129ae6465115e7d33c5a", null ],
    [ "k31Cine", "group__speakerArrangements.html#ga925534b26c3f13772f0363b44de830fb", null ],
    [ "k30Music", "group__speakerArrangements.html#ga8848385489d48df96843cd8022dbbfe1", null ],
    [ "k31Music", "group__speakerArrangements.html#ga34fbc53e44aafa8ca50155a58bd056fe", null ],
    [ "k40Cine", "group__speakerArrangements.html#gac1c674ad48a47ead5c1bd0b4d0e6611a", null ],
    [ "k41Cine", "group__speakerArrangements.html#gaa70d2ecf42316dbf7ea9147384b1d16b", null ],
    [ "k40Music", "group__speakerArrangements.html#ga2133b89c1fce6c11540a55ede3d00715", null ],
    [ "k41Music", "group__speakerArrangements.html#gac3ec49935f60ef5a877f21c6225274f5", null ],
    [ "k50", "group__speakerArrangements.html#gada66cacb0407add2f87505ba08b98095", null ],
    [ "k51", "group__speakerArrangements.html#ga5ed1fd3424cda0c720d08dab3cdacdec", null ],
    [ "k60Cine", "group__speakerArrangements.html#ga5c5769c0eac0d76ff06cc2b95cf15ca9", null ],
    [ "k61Cine", "group__speakerArrangements.html#gaf60226cc4b55554791dedf5ac9c6b46c", null ],
    [ "k60Music", "group__speakerArrangements.html#gadf94b622b8d58c498a49d37d9561f535", null ],
    [ "k61Music", "group__speakerArrangements.html#ga7c2a763f2db01800286568722f724c30", null ],
    [ "k70Cine", "group__speakerArrangements.html#ga957c53627e5492b9b62190be390255c1", null ],
    [ "k71Cine", "group__speakerArrangements.html#ga153beb2d5d562ed4fc8643bf51c711d8", null ],
    [ "k71CineFullFront", "group__speakerArrangements.html#ga329178a60998946671c5de893797dddf", null ],
    [ "k70Music", "group__speakerArrangements.html#ga2fb8698f83d75be166b99fdbce9e82f1", null ],
    [ "k71Music", "group__speakerArrangements.html#ga0dbaa8d90949e4084abb7878a5d5f91b", null ],
    [ "k71CineFullRear", "group__speakerArrangements.html#ga50d89ea22e10fe3acadb02c071288776", null ],
    [ "k71CineSideFill", "group__speakerArrangements.html#ga27352e019fb6f0d3b4d10b643f79d813", null ],
    [ "k71Proximity", "group__speakerArrangements.html#ga9ad1279216eaac4c4c2cd665e6d61c82", null ],
    [ "k80Cine", "group__speakerArrangements.html#ga2ebfc79a0e5ef338247e31239967632d", null ],
    [ "k81Cine", "group__speakerArrangements.html#gafae2531e75a317dd357fa09074fab4f6", null ],
    [ "k80Music", "group__speakerArrangements.html#gae026a8a57e8a9a408320616a0d289ece", null ],
    [ "k81Music", "group__speakerArrangements.html#ga4c68f76511df6119eca847b005105cd5", null ],
    [ "k90Cine", "group__speakerArrangements.html#ga6e5bea49421b1e65cb9e8e098436cc56", null ],
    [ "k91Cine", "group__speakerArrangements.html#ga6d6ccb80d89619c8085ac9a7283fc248", null ],
    [ "k100Cine", "group__speakerArrangements.html#gab0c0067c64c879551949be762f600af7", null ],
    [ "k101Cine", "group__speakerArrangements.html#ga87d1b8523518919bb9637a004c00448c", null ],
    [ "kAmbi1stOrderACN", "group__speakerArrangements.html#ga02d21f6bfee6423fceb6a3695954c33b", null ],
    [ "kAmbi2cdOrderACN", "group__speakerArrangements.html#ga6117e1aa058a519559fbea82adb0aa69", null ],
    [ "kAmbi3rdOrderACN", "group__speakerArrangements.html#ga1b19ef3d9cbdfb96c008f4586b186997", null ],
    [ "kAmbi4thOrderACN", "group__speakerArrangements.html#gaa7128399bc94194318d05a42a656b6c3", null ],
    [ "kAmbi5thOrderACN", "group__speakerArrangements.html#ga75c0d3966f966fdc114f3743693f6661", null ],
    [ "kAmbi6thOrderACN", "group__speakerArrangements.html#gacb03caa7a584d5c6e2c1dba585e17388", null ],
    [ "kAmbi7thOrderACN", "group__speakerArrangements.html#gaba508607de22c17a41421f3e012e9c6d", null ],
    [ "k80Cube", "group__speakerArrangements.html#ga44ee3dd3579cc26082915d76a28be70f", null ],
    [ "k40_4", "group__speakerArrangements.html#gae473d3c439f65d8948d6c2889be93490", null ],
    [ "k71CineTopCenter", "group__speakerArrangements.html#ga9c79cded90ddc1a1e366e1fbf4315334", null ],
    [ "k71CineCenterHigh", "group__speakerArrangements.html#gafca48c099db5b486edc4a79616b3f024", null ],
    [ "k70CineFrontHigh", "group__speakerArrangements.html#gac432eebae5c8256e872d754aaa7f5b3a", null ],
    [ "k70MPEG3D", "group__speakerArrangements.html#ga01056324cffd7c063a51196cd8fd6847", null ],
    [ "k50_2", "group__speakerArrangements.html#ga3a6e7551ec2aebccdb70236a29eaae2d", null ],
    [ "k71CineFrontHigh", "group__speakerArrangements.html#ga8e2c48c3830b09da02e7bb123f5916bd", null ],
    [ "k71MPEG3D", "group__speakerArrangements.html#gaf21f025b23bb45133395657787f88a13", null ],
    [ "k51_2", "group__speakerArrangements.html#ga915a918d766f639dfc9f15c8a8bd9ade", null ],
    [ "k70CineSideHigh", "group__speakerArrangements.html#ga7538b09e2e8f95cd13f370f21de7f9f6", null ],
    [ "k50_2_TS", "group__speakerArrangements.html#gad29f5880932646a417c0ea712454874c", null ],
    [ "k71CineSideHigh", "group__speakerArrangements.html#ga300b4574ad12477ff99286519b754dfe", null ],
    [ "k51_2_TS", "group__speakerArrangements.html#gac7c590bd9642823b634c33a5fa3d6cfd", null ],
    [ "k81MPEG3D", "group__speakerArrangements.html#ga1d7c7f813f01cd3f4478ecc81e46e82c", null ],
    [ "k41_4_1", "group__speakerArrangements.html#ga9bce1aee5d88c3554f787f3a4a44e7ff", null ],
    [ "k90", "group__speakerArrangements.html#gab04f1f4652d14e277671a0b62a8e8373", null ],
    [ "k50_4", "group__speakerArrangements.html#gade838b7c4cdbe2c7a8357e2cb710baf2", null ],
    [ "k91", "group__speakerArrangements.html#gac29f63756f056bf266ba0e2d26f143d4", null ],
    [ "k51_4", "group__speakerArrangements.html#ga9680715bcefe20b26397cab10f7fb18b", null ],
    [ "k50_4_1", "group__speakerArrangements.html#ga1b93e71fddaa428f500d5c00389e1983", null ],
    [ "k51_4_1", "group__speakerArrangements.html#gab9cbf9c14bff95ebbd0bd07275eb5302", null ],
    [ "k70_2", "group__speakerArrangements.html#ga4496b8a1fc103ed42e399eca71048d12", null ],
    [ "k71_2", "group__speakerArrangements.html#gaa6ebca6edf27a3858c2780043ee022e6", null ],
    [ "k91Atmos", "group__speakerArrangements.html#ga543a82154cd2675d7d8c4ef6680448dd", null ],
    [ "k70_3", "group__speakerArrangements.html#ga6f27378ab18dd47db2a3505c29d0df05", null ],
    [ "k72_3", "group__speakerArrangements.html#ga5fa2811d49376db2dc36460547ecf7b7", null ],
    [ "k70_4", "group__speakerArrangements.html#ga6246a745fadd335ea2e8ba88b4a4e507", null ],
    [ "k71_4", "group__speakerArrangements.html#gae15aef0c82b6f1be96a54fb616a1a7cb", null ],
    [ "k111MPEG3D", "group__speakerArrangements.html#gaacb60df68338ad8f622ea9a1f01416c8", null ],
    [ "k70_6", "group__speakerArrangements.html#gafd2c7f480119d8c17a533fb8d5948fd8", null ],
    [ "k71_6", "group__speakerArrangements.html#gaa4e5066c1a84a30aeadd0e76b74d57ba", null ],
    [ "k90_4", "group__speakerArrangements.html#ga6bbc13de7df2c9e8a7ff9950bd44ab39", null ],
    [ "k91_4", "group__speakerArrangements.html#ga4f9e89d3c8dbbb4dac1e2cb67633615b", null ],
    [ "k90_6", "group__speakerArrangements.html#ga88accb0a3074c3fb6eb3fdb490b21c62", null ],
    [ "k91_6", "group__speakerArrangements.html#gaaa5bdf5a10ab4f4930c1ecf4efeb3f95", null ],
    [ "k100", "group__speakerArrangements.html#ga6cadcafb161f16aa7edcc676604e4def", null ],
    [ "k50_5", "group__speakerArrangements.html#ga07f09cbbdc4d96c628d69523a40d67ba", null ],
    [ "k101", "group__speakerArrangements.html#ga13c1699c11fba17352b83a1b3a7cfcc8", null ],
    [ "k101MPEG3D", "group__speakerArrangements.html#gad74c12ca20962432ba88df9807a9f156", null ],
    [ "k51_5", "group__speakerArrangements.html#ga6c9595514bf015a122ca14bdae89a6b1", null ],
    [ "k102", "group__speakerArrangements.html#ga07bcd44b9922095ccd79f2195ad80e2b", null ],
    [ "k52_5", "group__speakerArrangements.html#gad9225daa491f684badf79d0de20a83f9", null ],
    [ "k110", "group__speakerArrangements.html#gaf19e8a3b3f0d3a2c0e9587f6cc9b1411", null ],
    [ "k50_6", "group__speakerArrangements.html#ga1ab315f9942e83ed753c115f427d16a3", null ],
    [ "k111", "group__speakerArrangements.html#ga740b694bcebcd228836a5610feeeb929", null ],
    [ "k51_6", "group__speakerArrangements.html#ga55a33b6e8c3d1e8a6289df2bcb32e49c", null ],
    [ "k122", "group__speakerArrangements.html#gadac6b9c961b9ffdf682f8ff85ea6be64", null ],
    [ "k72_5", "group__speakerArrangements.html#ga48d6c553097c808e4d720a20af732555", null ],
    [ "k130", "group__speakerArrangements.html#ga58d4fdbfb02cceca73527bcbf17bf930", null ],
    [ "k131", "group__speakerArrangements.html#gac672a7aa5cabd6a5d4c4441e6aadc925", null ],
    [ "k140", "group__speakerArrangements.html#gaf7c32506aada727a39b6f30173a5a572", null ],
    [ "k60_4_4", "group__speakerArrangements.html#gab037598e5c1606c226c0a98e2167ef96", null ],
    [ "k220", "group__speakerArrangements.html#ga39dd41aa48652def01c2b774f3a46a02", null ],
    [ "k100_9_3", "group__speakerArrangements.html#gab7b313f0ee880f3b9f7ec8494ae6ce81", null ],
    [ "k222", "group__speakerArrangements.html#ga80683d5816c4db7345c6e25dfdbc87a0", null ],
    [ "k102_9_3", "group__speakerArrangements.html#gaa6fae1c3c9c0603d95b8fec74a145309", null ],
    [ "k50_5_3", "group__speakerArrangements.html#gaddebe89c64428865b798a9992534b087", null ],
    [ "k51_5_3", "group__speakerArrangements.html#ga52ca6a659ccabd38af3e0e5b3af932d2", null ],
    [ "k50_2_2", "group__speakerArrangements.html#ga447cbeb4a66d7a12f6c36240b666331a", null ],
    [ "k50_4_2", "group__speakerArrangements.html#ga22796d2f7f109bde16a525429c8194af", null ],
    [ "k70_4_2", "group__speakerArrangements.html#ga419904483b34cd1d809100f7388d50b7", null ],
    [ "k50_5_Sony", "group__speakerArrangements.html#gadb8c4b83f39868ff4da93be72a3dfef0", null ],
    [ "k40_2_2", "group__speakerArrangements.html#gabd12a0facfe37226a9f5601ed1b5de4d", null ],
    [ "k40_4_2", "group__speakerArrangements.html#gace185a0a2ef646fc3dd9b26777acc25d", null ],
    [ "k50_3_2", "group__speakerArrangements.html#ga1c30f7ea8d0b380ec954fd35e1cbc33e", null ],
    [ "k30_5_2", "group__speakerArrangements.html#ga8ace2cc7e8e56351d3df5f95bac9ff8f", null ],
    [ "k40_4_4", "group__speakerArrangements.html#ga5cd8e94e229c89d617dfea91d364c9e7", null ],
    [ "k50_4_4", "group__speakerArrangements.html#gacafff17c0c21e0030c6bb0cce8b72576", null ],
    [ "kStringEmpty", "group__speakerArrangements.html#ga38c557da6a4db5884d2d688c30cc5553", null ],
    [ "kStringMono", "group__speakerArrangements.html#gacc3c2f0d3a1a7cefebcd21afcaff0a33", null ],
    [ "kStringStereo", "group__speakerArrangements.html#gaa8801dd84fb2f8566448a99c418d1185", null ],
    [ "kStringStereoR", "group__speakerArrangements.html#ga7baad18ef660784d5ed89c95d0f16aa9", null ],
    [ "kStringStereoC", "group__speakerArrangements.html#ga2057f29b65596edf1cb80ccc6a041b83", null ],
    [ "kStringStereoSide", "group__speakerArrangements.html#gabab50191c9f7c6a497f7d148cc3a9741", null ],
    [ "kStringStereoCLfe", "group__speakerArrangements.html#gaa1f7cbf8a6fe0184d7ab51fcb3c4792a", null ],
    [ "kStringStereoTF", "group__speakerArrangements.html#ga39cdd95afef98e1901ebdb99183e91f2", null ],
    [ "kStringStereoTS", "group__speakerArrangements.html#gaf980dfe2b66f77f49e5cc064e29baf90", null ],
    [ "kStringStereoTR", "group__speakerArrangements.html#ga31865a34aa4e3eca16df14729ff1629f", null ],
    [ "kStringStereoBF", "group__speakerArrangements.html#ga50527ffdd77c1df3a01d2656abdcfaca", null ],
    [ "kStringCineFront", "group__speakerArrangements.html#ga5844248872630578a50942ea6be5da50", null ],
    [ "kString30Cine", "group__speakerArrangements.html#ga546feab92a740e05c378ee7ac40f35cd", null ],
    [ "kString30Music", "group__speakerArrangements.html#ga53f43e261801293edcef4a1ad84b279d", null ],
    [ "kString31Cine", "group__speakerArrangements.html#ga1e80c914f10746070e3ffe6e85eb5c1f", null ],
    [ "kString31Music", "group__speakerArrangements.html#ga137e13924264d25e2b23315c90a1a735", null ],
    [ "kString40Cine", "group__speakerArrangements.html#ga6bb5e6215f1f55441b2d63e1da3d826d", null ],
    [ "kString40Music", "group__speakerArrangements.html#ga0f4c3361e3f81439c234f22f2c526829", null ],
    [ "kString41Cine", "group__speakerArrangements.html#ga8b4f4ca5b48687d28d352f0fcfae57df", null ],
    [ "kString41Music", "group__speakerArrangements.html#ga9a75f791d9b04c26b732bc3501c26ee6", null ],
    [ "kString50", "group__speakerArrangements.html#ga67879f0e2d9733cd1a725c10b6bd41ac", null ],
    [ "kString51", "group__speakerArrangements.html#gad0d54db82db6123d96d1f586b443bca3", null ],
    [ "kString60Cine", "group__speakerArrangements.html#ga6a60a614644af6eb7185b1ca3c863146", null ],
    [ "kString60Music", "group__speakerArrangements.html#ga792624a39e54bdeb84703f79b9180370", null ],
    [ "kString61Cine", "group__speakerArrangements.html#ga7664212680fd954f8d3bdec7ee52a0a5", null ],
    [ "kString61Music", "group__speakerArrangements.html#gac847eadaa1938e45601af71cb37737b5", null ],
    [ "kString70Cine", "group__speakerArrangements.html#ga605e76c32caeb4f0d85ada0ffd422b89", null ],
    [ "kString70CineOld", "group__speakerArrangements.html#ga34a5ea5d19e507a4cc75aaf5ca038e70", null ],
    [ "kString70Music", "group__speakerArrangements.html#ga5bda8dedc7edcfa8f36b5a99509c9449", null ],
    [ "kString70MusicOld", "group__speakerArrangements.html#ga35ac01519b72d4f2ebc88a7621467378", null ],
    [ "kString71Cine", "group__speakerArrangements.html#ga3475b1b161d22aca3939960e461307a5", null ],
    [ "kString71CineOld", "group__speakerArrangements.html#ga6e0d74b112ae74fe8e74dc190db3b01b", null ],
    [ "kString71Music", "group__speakerArrangements.html#ga8840a665e6fa4dac19167726473d6072", null ],
    [ "kString71MusicOld", "group__speakerArrangements.html#gaa259ec989476ec18dd30dbbe9edaa6a8", null ],
    [ "kString71CineTopCenter", "group__speakerArrangements.html#ga6f792b0962f42ec4f133cb64de72d31e", null ],
    [ "kString71CineCenterHigh", "group__speakerArrangements.html#gabbfecee6091fbab1bbd2d3e073b86f5d", null ],
    [ "kString71CineFullRear", "group__speakerArrangements.html#gab78c124e88ad66fcd06aa09f3871320e", null ],
    [ "kString51_2", "group__speakerArrangements.html#gaa4edb550a1fa7674cbd3d4f36057739e", null ],
    [ "kString50_2", "group__speakerArrangements.html#ga541d217c8f043728ff06915e44c8bdbd", null ],
    [ "kString50_2TopSide", "group__speakerArrangements.html#ga230b03c83c3ad137460b4ab78fdede4a", null ],
    [ "kString51_2TopSide", "group__speakerArrangements.html#gaa642ca60e40a5c4cfb45a22ffc13d41d", null ],
    [ "kString71Proximity", "group__speakerArrangements.html#ga30a288eb79dfa6b08afb569234e831d2", null ],
    [ "kString80Cine", "group__speakerArrangements.html#gae7259d85e37e87f3734e0645a890312b", null ],
    [ "kString80Music", "group__speakerArrangements.html#ga35c11fa95eb4ed5340307b725c53180d", null ],
    [ "kString40_4", "group__speakerArrangements.html#ga7862d38f234a211df2a6273bbce64000", null ],
    [ "kString81Cine", "group__speakerArrangements.html#gaf949196ba6ad50b12f2522524ae2079a", null ],
    [ "kString81Music", "group__speakerArrangements.html#ga301aef980be40689f6a32d2f2ea5990d", null ],
    [ "kString90Cine", "group__speakerArrangements.html#gaa72e158f204f9834347b1d811f0e1e1c", null ],
    [ "kString91Cine", "group__speakerArrangements.html#gac31faedafc0d6ef570cb6b5098b189b2", null ],
    [ "kString100Cine", "group__speakerArrangements.html#ga42ee84421893fe9759b400d0bd3becaf", null ],
    [ "kString101Cine", "group__speakerArrangements.html#ga4623d9c5afc0883aa25409a89fc4b01c", null ],
    [ "kString52_5", "group__speakerArrangements.html#ga2abe9ebdaff5cae2f2581a558cb3eb02", null ],
    [ "kString72_5", "group__speakerArrangements.html#ga57a18ac1a2f5453752d9350c6b2795d3", null ],
    [ "kString50_4", "group__speakerArrangements.html#gacfc39ea40d9b3ee2c64ee332aadf9dc5", null ],
    [ "kString51_4", "group__speakerArrangements.html#ga3087980012d3e5dee03f977677790623", null ],
    [ "kString50_4_1", "group__speakerArrangements.html#gaa5253e1dbbc9ed637733b166da5a7304", null ],
    [ "kString51_4_1", "group__speakerArrangements.html#ga8a61d9d214b5884f8187873046350cd2", null ],
    [ "kString70_2", "group__speakerArrangements.html#ga45b8a48950dee4f9713bda0a5b9ca196", null ],
    [ "kString71_2", "group__speakerArrangements.html#gaeed20d0347a2ea4100a9b58990c5bcc1", null ],
    [ "kString70_3", "group__speakerArrangements.html#ga0a7e4c0b7f089d11a7fb48afac04a074", null ],
    [ "kString72_3", "group__speakerArrangements.html#ga82c4d879242407689ce2d58d127d96d0", null ],
    [ "kString70_4", "group__speakerArrangements.html#gabff1c300f5f6d675842dc5e8492b973e", null ],
    [ "kString71_4", "group__speakerArrangements.html#gad07e3ef7063ba3b63b8699fceab70e14", null ],
    [ "kString70_6", "group__speakerArrangements.html#ga07019a8f7d26ec6d67e3b21a4909ad50", null ],
    [ "kString71_6", "group__speakerArrangements.html#ga49ccafdb4653781c17fa20f933a29af2", null ],
    [ "kString90_4", "group__speakerArrangements.html#ga28381a787f5d2e84e16067329d0efc00", null ],
    [ "kString91_4", "group__speakerArrangements.html#ga3b0b6d1ed6af07daa84a016f9a594d59", null ],
    [ "kString90_6", "group__speakerArrangements.html#gaa1fe4d708fa32e7b1ddeb892fa073509", null ],
    [ "kString91_6", "group__speakerArrangements.html#gab8ec511d08a024efcfc54258ddaf48cf", null ],
    [ "kString50_5", "group__speakerArrangements.html#ga78e757a9d10fe70b7ee5a16ddd02cd1e", null ],
    [ "kString51_5", "group__speakerArrangements.html#ga6ad5cb522b313a38c2134c7706b73027", null ],
    [ "kString50_6", "group__speakerArrangements.html#gad826493413cb2611f94658e9ed2c2520", null ],
    [ "kString51_6", "group__speakerArrangements.html#gad41abd22120392163e10a8699f174346", null ],
    [ "kString130", "group__speakerArrangements.html#gac7d25b1cc65c51e76c225ae50c4116ba", null ],
    [ "kString131", "group__speakerArrangements.html#gaf610b7be568618c5d5c3aa20d4cf2ecb", null ],
    [ "kString41_4_1", "group__speakerArrangements.html#ga2b7412e5a07fbbce4e641a8fa7b81001", null ],
    [ "kString60_4_4", "group__speakerArrangements.html#ga7c9500be12cf3867ab2009b13a490f8f", null ],
    [ "kString220", "group__speakerArrangements.html#gaebcce0418f6b0300b6f862766f7f58e2", null ],
    [ "kString222", "group__speakerArrangements.html#gaad33c8ed818e1d8f2a30195dadf50af9", null ],
    [ "kString50_5_3", "group__speakerArrangements.html#gaf5367c0d3c1ca0a638ecb2dc5198d5a1", null ],
    [ "kString51_5_3", "group__speakerArrangements.html#gabfd1ce52185e9de239a2d86cdfaa96ae", null ],
    [ "kString50_2_2", "group__speakerArrangements.html#ga7e8fcff06d6336d9e074bb52126906c1", null ],
    [ "kString50_4_2", "group__speakerArrangements.html#gab315be1e08a3fd8881483cb595d04977", null ],
    [ "kString70_4_2", "group__speakerArrangements.html#ga8ef7ca32e5928ef168cffbfdf5eb74ec", null ],
    [ "kString50_5_Sony", "group__speakerArrangements.html#gae67ecf106b1633e3bab42ce580dd8b9f", null ],
    [ "kString40_2_2", "group__speakerArrangements.html#ga724f21f7494bf592885a7637069e8b35", null ],
    [ "kString40_4_2", "group__speakerArrangements.html#ga5a004301eeca0b6240d2b13f804c7bff", null ],
    [ "kString50_3_2", "group__speakerArrangements.html#ga2f656b124363f1656327bf5fb9e7dc48", null ],
    [ "kString30_5_2", "group__speakerArrangements.html#ga55e31b6eaebd31f8c42e2e5daaf6443a", null ],
    [ "kString40_4_4", "group__speakerArrangements.html#gab9474808a2720d77eb38733cb2e5e831", null ],
    [ "kString50_4_4", "group__speakerArrangements.html#ga3151e2974547b528528e913542dd5292", null ],
    [ "kStringAmbi1stOrder", "group__speakerArrangements.html#gae989a0ed646d1b90e700b6599b87e9c5", null ],
    [ "kStringAmbi2cdOrder", "group__speakerArrangements.html#ga57421a0b5dd2faacfc03c8b4df47c626", null ],
    [ "kStringAmbi3rdOrder", "group__speakerArrangements.html#gab530c1e2f6dfd766cfb9f1b4f11b6ddf", null ],
    [ "kStringAmbi4thOrder", "group__speakerArrangements.html#ga24d4f4886be5ec7ac6fa441212f9b402", null ],
    [ "kStringAmbi5thOrder", "group__speakerArrangements.html#gaf80df1bbb9f317dd4c11ac891a2f8f40", null ],
    [ "kStringAmbi6thOrder", "group__speakerArrangements.html#ga1d0d1ec6684406ef2ca93eb7bd921bb3", null ],
    [ "kStringAmbi7thOrder", "group__speakerArrangements.html#gaeae5f636bab30a1fc18cb36210b23b56", null ],
    [ "kStringMonoS", "group__speakerArrangements.html#ga646cd09e52190d60f2d4ca83faf915aa", null ],
    [ "kStringStereoS", "group__speakerArrangements.html#ga54144ab0e1dd2babcf5e720950cf7e24", null ],
    [ "kStringStereoRS", "group__speakerArrangements.html#ga63f3673e0a9ad13c3788b583d4fac61b", null ],
    [ "kStringStereoCS", "group__speakerArrangements.html#ga3cb0fc4337ff0f43bf119b20c7f5d810", null ],
    [ "kStringStereoSS", "group__speakerArrangements.html#ga22b0cac49e8ef5b3d9a1836abd021720", null ],
    [ "kStringStereoCLfeS", "group__speakerArrangements.html#gaa6cc8eae43caf89b778136bbb05fc09a", null ],
    [ "kStringStereoTFS", "group__speakerArrangements.html#gacff5991a9dd2a3d5a415d499bcfd681b", null ],
    [ "kStringStereoTSS", "group__speakerArrangements.html#gad25d6a1fe574b28440e6b95d94978edb", null ],
    [ "kStringStereoTRS", "group__speakerArrangements.html#gac777248ebd6fa592c82b7bcb78f9301e", null ],
    [ "kStringStereoBFS", "group__speakerArrangements.html#ga8a0f76c380e173edac9016a3dcfc45bb", null ],
    [ "kStringCineFrontS", "group__speakerArrangements.html#ga19addfe92087609dea4ef8c257becfbf", null ],
    [ "kString30CineS", "group__speakerArrangements.html#gadf31296b53805c54ae5563807650b24e", null ],
    [ "kString30MusicS", "group__speakerArrangements.html#gaae88a2f1492097d9d64e073cd7943722", null ],
    [ "kString31CineS", "group__speakerArrangements.html#ga7e65cdf6a6fc4d8aeffc59a7b1a66a1f", null ],
    [ "kString31MusicS", "group__speakerArrangements.html#ga1b7e67dba5f5333b64eb847d3d78668d", null ],
    [ "kString40CineS", "group__speakerArrangements.html#ga531abc9ded9f3e0474010cdb22557d0d", null ],
    [ "kString40MusicS", "group__speakerArrangements.html#ga51fdeb3143151508f6d94344431ce9de", null ],
    [ "kString41CineS", "group__speakerArrangements.html#ga3789962208da8454667b34aa666981db", null ],
    [ "kString41MusicS", "group__speakerArrangements.html#ga54a60dca7c8b8556b398867c51dc1e00", null ],
    [ "kString50S", "group__speakerArrangements.html#gab8903815699fa69a4fd8ec717317dc29", null ],
    [ "kString51S", "group__speakerArrangements.html#gafbb743a8f1f0002bae234e2d5910ee8a", null ],
    [ "kString60CineS", "group__speakerArrangements.html#ga16ff5025a411dc1c3b7fc305dfe53073", null ],
    [ "kString60MusicS", "group__speakerArrangements.html#gab2533387651492af2317e897bd94bf26", null ],
    [ "kString61CineS", "group__speakerArrangements.html#ga2f2f2eb56bcf2977ad670a752c69d793", null ],
    [ "kString61MusicS", "group__speakerArrangements.html#ga81d034a4b036e9e9bd0be527711db6fc", null ],
    [ "kString70CineS", "group__speakerArrangements.html#gae72794cddb19856e3ec62e33d290176d", null ],
    [ "kString70MusicS", "group__speakerArrangements.html#ga5f3a9a34dc5798908f848f0b881b8c06", null ],
    [ "kString71CineS", "group__speakerArrangements.html#ga4b10dc09ef678e66e90330f5b6b591d0", null ],
    [ "kString71MusicS", "group__speakerArrangements.html#gaec8cf18e8bfd88584375e66b67fde24e", null ],
    [ "kString80CineS", "group__speakerArrangements.html#gaf3da1b6a98e9f9d01e8141f205f35764", null ],
    [ "kString80MusicS", "group__speakerArrangements.html#ga8204788aa5b2fce1730c157dc8a9239f", null ],
    [ "kString81CineS", "group__speakerArrangements.html#gafe30ad0333248d38dfd6a162879a97a6", null ],
    [ "kString81MusicS", "group__speakerArrangements.html#ga5b7279077b689fa26044fc2520a413c7", null ],
    [ "kString40_4S", "group__speakerArrangements.html#ga4b1241bc660c2cd6fe752e2f3a1d6de7", null ],
    [ "kString71CineTopCenterS", "group__speakerArrangements.html#ga006f007337addc5c126777bc9e9b774d", null ],
    [ "kString71CineCenterHighS", "group__speakerArrangements.html#gaf0c13b30d128debc8f8976927a321f48", null ],
    [ "kString71CineFullRearS", "group__speakerArrangements.html#ga5e313aadeb060bc3dc88d17ca2e81a06", null ],
    [ "kString50_2S", "group__speakerArrangements.html#ga0a881b193fdb5ee3949d4da3501cf4c5", null ],
    [ "kString51_2S", "group__speakerArrangements.html#ga9544be5659ac804df18bc1ac524e7305", null ],
    [ "kString50_2TopSideS", "group__speakerArrangements.html#ga80f213e5708edd67d2d834a51d247e68", null ],
    [ "kString51_2TopSideS", "group__speakerArrangements.html#gaca11b7e3831e00dd7b5828111675411a", null ],
    [ "kString71ProximityS", "group__speakerArrangements.html#ga86fc6ff2265855e22d3573786e05af2d", null ],
    [ "kString90CineS", "group__speakerArrangements.html#ga4a24b9cdab9b5ed5af4ae28cbe8f7205", null ],
    [ "kString91CineS", "group__speakerArrangements.html#gabebe500b3d27127ae844c7fcabb854f0", null ],
    [ "kString100CineS", "group__speakerArrangements.html#ga341a094c1693e21946264eb706155c32", null ],
    [ "kString101CineS", "group__speakerArrangements.html#ga7ce63c640f335bc95fb4203dbe117a44", null ],
    [ "kString50_4S", "group__speakerArrangements.html#ga8f720e94eddcbd5b60ad0bce56349883", null ],
    [ "kString51_4S", "group__speakerArrangements.html#ga076816df2f77a47f7ffa7f954624886a", null ],
    [ "kString50_4_1S", "group__speakerArrangements.html#ga985a5db10bde4ce9b038b7ff4cb7d0dd", null ],
    [ "kString51_4_1S", "group__speakerArrangements.html#gab859a00d3cac8780a78e2eff99d5646e", null ],
    [ "kString70_2S", "group__speakerArrangements.html#gae4e0eb4b5b2a9d8be26313f2bacfdf0e", null ],
    [ "kString71_2S", "group__speakerArrangements.html#ga50d7d7630353ff6f0512be5aa2277fc4", null ],
    [ "kString70_3S", "group__speakerArrangements.html#gacef782ab6e649c141730cb6f6a083532", null ],
    [ "kString72_3S", "group__speakerArrangements.html#gaa19c374dcf42888be53cf358525e338b", null ],
    [ "kString70_4S", "group__speakerArrangements.html#ga47554e8c117d0119288c796708533bd5", null ],
    [ "kString71_4S", "group__speakerArrangements.html#gac09c0be94436acb5d49fe4fb69f13ffe", null ],
    [ "kString70_6S", "group__speakerArrangements.html#ga9286dbbe48dd048c6096935139c293e1", null ],
    [ "kString71_6S", "group__speakerArrangements.html#ga9763b5d2b528848fc90deec34999ca90", null ],
    [ "kString90_4S", "group__speakerArrangements.html#ga6d4ef306235169341804482b1be208fe", null ],
    [ "kString91_4S", "group__speakerArrangements.html#ga1b17445201a92bee4c23dd16e5cd1728", null ],
    [ "kString90_6S", "group__speakerArrangements.html#gac89dcac8a9acb594a3e406cc5241d650", null ],
    [ "kString91_6S", "group__speakerArrangements.html#gaf0b16e15ff6616a3e481b879d3b4c53f", null ],
    [ "kString50_5S", "group__speakerArrangements.html#ga597dea323dcd6ebf7a8f79e222744396", null ],
    [ "kString51_5S", "group__speakerArrangements.html#ga693724048ed9aa6572030b22a0c722d5", null ],
    [ "kString50_5_SonyS", "group__speakerArrangements.html#ga7697d22e6e22fa8c6948bd482737ce62", null ],
    [ "kString50_6S", "group__speakerArrangements.html#gac97a088b45e2fde1967424d9b81fedd3", null ],
    [ "kString51_6S", "group__speakerArrangements.html#ga8d36f86e550d1e385d7df0f1b95fe644", null ],
    [ "kString130S", "group__speakerArrangements.html#gaccdab4f0e651d4c1b0b850e6c8edb9f4", null ],
    [ "kString131S", "group__speakerArrangements.html#ga9cdfa2ff878225396509ca7b25af7f1f", null ],
    [ "kString52_5S", "group__speakerArrangements.html#gab885c9cdd40c853e3fa0d814cbe405fc", null ],
    [ "kString72_5S", "group__speakerArrangements.html#gad91914c14ceb3f46c9b03dcba94c4da8", null ],
    [ "kString41_4_1S", "group__speakerArrangements.html#ga95a8ec3f36de03bb6b9f3f1be339f889", null ],
    [ "kString30_5_2S", "group__speakerArrangements.html#ga0049a81a50306a41abd45f0871e13173", null ],
    [ "kString40_2_2S", "group__speakerArrangements.html#ga2211a95b3ce1e534c1da0ad1824c4018", null ],
    [ "kString40_4_2S", "group__speakerArrangements.html#ga8091e05a3cda7c9ce2c16b0e819f7a01", null ],
    [ "kString40_4_4S", "group__speakerArrangements.html#gaebd0216ab437c17333f06b23acc1cb17", null ],
    [ "kString50_4_4S", "group__speakerArrangements.html#ga2990e1e187ac62b502407cad4fea5ae7", null ],
    [ "kString60_4_4S", "group__speakerArrangements.html#ga272cd10cad55c182440769f24c656cc0", null ],
    [ "kString50_5_3S", "group__speakerArrangements.html#ga36a920fcf904e74af45153417e6bda20", null ],
    [ "kString51_5_3S", "group__speakerArrangements.html#ga1f2886d3047f9f7b5fd699b1d9fa6a79", null ],
    [ "kString50_2_2S", "group__speakerArrangements.html#ga834a0174a7e6edd7f975bc5aebabd8c2", null ],
    [ "kString50_3_2S", "group__speakerArrangements.html#gad7fad738b417a8446da419af519f64de", null ],
    [ "kString50_4_2S", "group__speakerArrangements.html#ga4a84febf8ecee1a6ba6c0a8786d378c3", null ],
    [ "kString70_4_2S", "group__speakerArrangements.html#ga6ad6a86612666400c64e041499a0f0b4", null ],
    [ "kString222S", "group__speakerArrangements.html#gab442cbf6e2447ea3a762e0c9c891d274", null ],
    [ "kString220S", "group__speakerArrangements.html#ga9df1f69930cf3ab747d645b40ba073c1", null ],
    [ "kStringAmbi1stOrderS", "group__speakerArrangements.html#ga319dbf573206d0bb1a8b77e7f476548d", null ],
    [ "kStringAmbi2cdOrderS", "group__speakerArrangements.html#ga81cbc11f839866ed8a91dc903e5a6d97", null ],
    [ "kStringAmbi3rdOrderS", "group__speakerArrangements.html#gab2317fa07e1e7ee2cfce204a07945c40", null ],
    [ "kStringAmbi4thOrderS", "group__speakerArrangements.html#ga839832f21fa2e52200f91f09ad492209", null ],
    [ "kStringAmbi5thOrderS", "group__speakerArrangements.html#gaadef9295f857718379440bb7ad4d3382", null ],
    [ "kStringAmbi6thOrderS", "group__speakerArrangements.html#ga7a433d89eecd7b1c0bde77f0741a398b", null ],
    [ "kStringAmbi7thOrderS", "group__speakerArrangements.html#gaf509dd6c5d2edb6286c52038f69b8c7e", null ]
];